@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/AABB_tree/include/CGAL/AABB_traits_3.h $
-// $Id: include/CGAL/AABB_traits_3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/AABB_tree/include/CGAL/AABB_traits_3.h $
+// $Id: include/CGAL/AABB_traits_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -302,12 +302,11 @@ public:
     typename AT::Bounding_box operator()(ConstPrimitiveIterator first,
                                          ConstPrimitiveIterator beyond) const
     {
-      typename AT::Bounding_box bbox = m_traits.compute_bbox(*first,m_traits.bbm);
-      for(++first; first != beyond; ++first)
-        {
-          bbox = bbox + m_traits.compute_bbox(*first,m_traits.bbm);
-        }
-      return bbox;
+      return std::accumulate(first, beyond,
+        typename AT::Bounding_box{} /* empty bbox */,
+        [this](const typename AT::Bounding_box& bbox, const Primitive& pr) {
+          return bbox + m_traits.compute_bbox(pr, m_traits.bbm);
+        });
     }
 
   };
