@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/Alpha_wrap_3.h $
-// $Id: include/CGAL/Alpha_wrap_3/internal/Alpha_wrap_3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Alpha_wrap_3/include/CGAL/Alpha_wrap_3/internal/Alpha_wrap_3.h $
+// $Id: include/CGAL/Alpha_wrap_3/internal/Alpha_wrap_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Pierre Alliez
@@ -348,7 +348,7 @@ public:
 
 #ifdef CGAL_AW3_TIMER
       t.stop();
-      std::cout << "Manifoldness post-processing took: " << t.time() << " s." << std::endl;
+      std::cout << "Manifoldness postprocessing took: " << t.time() << " s." << std::endl;
       t.reset();
       t.start();
 #endif
