@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Arrangement_on_surface_2/include/CGAL/Arr_algebraic_segment_traits_2.h $
-// $Id: include/CGAL/Arr_algebraic_segment_traits_2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Arrangement_on_surface_2/include/CGAL/Arr_algebraic_segment_traits_2.h $
+// $Id: include/CGAL/Arr_algebraic_segment_traits_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -33,11 +33,10 @@
 
 namespace CGAL {
 
-template< class Coefficient_ >
+template <class Coefficient_>
 class Arr_algebraic_segment_traits_2 {
 
 public:
-
     enum Site_of_point {
         POINT_IN_INTERIOR = 0,
         MIN_ENDPOINT = -1,
@@ -57,16 +56,15 @@ public:
 
     typedef  CGAL::Arr_algebraic_segment_traits_2<Coefficient> Self;
 
-    // Default constructor
+    // constructs default
     Arr_algebraic_segment_traits_2 () {}
 
 
-    // Copy constructor
+    // constructs copy
     Arr_algebraic_segment_traits_2 (const  Self& /* s */) { /* No state...*/}
 
-    // Assignment operator
-    const Self& operator= (const Self& s)
-        {return s;}
+    // assigns
+    const Self& operator= (const Self& s) { return s; }
 
     // public types
 
@@ -75,7 +73,7 @@ public:
 
     typedef typename Algebraic_kernel_d_2::Polynomial_2 Polynomial_2;
 
-    /// public types for ArrangementTraits_2
+    /// public types for AosTraits_2
 
     typedef typename Algebraic_kernel_d_2::Curve_analysis_2 Curve_2;
 
@@ -613,11 +611,7 @@ public:
         return Construct_curve_2(&CKvA_2::instance());
     }
 
-
-
-
-
-/*
+  /*
 
   // additional functionality (for not introducing a "general" arc)
 
@@ -650,12 +644,12 @@ public:
 
   };
 
-*/
+  */
 
 };
 
-} //namespace CGAL
+} // namespace CGAL
 
 #include <CGAL/enable_warnings.h>
 
-#endif // CGAL_ARR_ALGEBRAIC_SEGMENT_TRAITS_H
+#endif
