@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h $
-// $Id: include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Arrangement_on_surface_2/include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h $
+// $Id: include/CGAL/Arrangement_2/Arrangement_on_surface_2_global.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -264,7 +264,7 @@ insert_empty(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
    * If the type C_visitor::Geometry_traits_2 is the same as the type
    * GeometryTraits_2, use a reference to GeometryTraits_2 to avoid constructing
    * a new one.  Otherwise, instantiate a local variable of the former and
-   * provide the later as a single parameter to the constructor.
+   * provide the latter as a single parameter to the constructor.
    *
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
@@ -319,7 +319,7 @@ void insert_empty(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>&
    * If the type C_visitor::Geometry_traits_2 is the same as the type
    * GeometryTraits_2, use a reference to GeometryTraits_2 to avoid constructing
    * a new one.  Otherwise, instantiate a local variable of the former and
-   * provide the later as a single parameter to the constructor.
+   * provide the latter as a single parameter to the constructor.
    *
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
@@ -372,7 +372,7 @@ void insert_non_empty(Arrangement_on_surface_2<GeometryTraits_2,
    * If the type Igt2 is the same as the type
    * GeometryTraits_2, use a reference to GeometryTraits_2 to avoid constructing
    * a new one.  Otherwise, instantiate a local variable of the former and
-   * provide the later as a single parameter to the constructor.
+   * provide the latter as a single parameter to the constructor.
    *
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
@@ -972,7 +972,7 @@ non_intersecting_insert_non_empty(Arrangement_on_surface_2<GeometryTraits_2,
    * If the type Nxi_visitor::Geometry_traits_2 is the same as the type
    * GeometryTraits_2, use a reference to GeometryTraits_2 to avoid constructing
    * a new one.  Otherwise, instantiate a local variable of the former and
-   * provide the later as a single parameter to the constructor.
+   * provide the latter as a single parameter to the constructor.
    *
    * Use the form 'A a(*b);' and not ''A a = b;' to handle the case where A has
    * only an implicit constructor, (which takes *b as a parameter).
@@ -1568,7 +1568,7 @@ template <typename GeometryTraits_2, typename TopologyTraits,
           typename PointLocation>
 bool
 do_intersect(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
-             const typename GeometryTraits_2::X_monotone_curve_2& c,
+             const typename GeometryTraits_2::Curve_2& c,
              const PointLocation& pl, std::is_same<int, double>::type)
 {
   typedef GeometryTraits_2                              Gt2;
@@ -1607,7 +1607,7 @@ do_intersect(Arrangement_on_surface_2<GeometryTraits_2, TopologyTraits>& arr,
     // Check whether the isolated point lies inside a face (otherwise,
     // it coincides with a vertex or an edge).
     auto obj = pl.locate(*iso_p);
-    if (std::get_if<Face_const_handle>(&x_obj) != nullptr) return true;
+    if (std::get_if<Face_const_handle>(&obj) != nullptr) return true;
   }
 
   // If we reached here, the curve does not intersect the arrangement.
