@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Circular_kernel_2/include/CGAL/Circular_kernel_2/function_objects_polynomial_circular.h $
-// $Id: include/CGAL/Circular_kernel_2/function_objects_polynomial_circular.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Circular_kernel_2/include/CGAL/Circular_kernel_2/function_objects_polynomial_circular.h $
+// $Id: include/CGAL/Circular_kernel_2/function_objects_polynomial_circular.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Monique Teillaud, Sylvain Pion, Pedro Machado
@@ -30,148 +30,115 @@
 namespace CGAL {
 namespace CircularFunctors {
 
+#define CGAL_CIRCULAR_KERNEL_MACRO_FUNCTOR_COMPARE_(V)\
+template < class CK > \
+  class Compare_ ##V## _2 {\
+    /*: public CK::Linear_kernel::Compare_ ##V## _2{*/\
+    typedef typename CK::Comparison_result Comparison_result;\
+    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;\
+    typedef typename CK::Linear_kernel::Compare_ ##V## _2 Linear_Compare_ ##V## _2;\
+  public:\
+    template <class... Args>\
+    Comparison_result\
+    operator()(const Args&... args) const\
+    { return Linear_Compare_ ##V## _2()(args...); }\
+    /*using CK::Linear_kernel::Compare_ ##V## _2::operator();*/\
+    Comparison_result\
+    operator() (const Circular_arc_point_2 &p0,\
+                const Circular_arc_point_2 &p1) const\
+    { return CircularFunctors::compare_ ##V <CK>(p0, p1); }\
+  };\
 
-  template < class CK >
-  class Compare_x_2
-    : public CK::Linear_kernel::Compare_x_2
-  {
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-    typedef typename CK::Point_2 Point_2;
+  CGAL_CIRCULAR_KERNEL_MACRO_FUNCTOR_COMPARE_(x)
+  CGAL_CIRCULAR_KERNEL_MACRO_FUNCTOR_COMPARE_(y)
+  CGAL_CIRCULAR_KERNEL_MACRO_FUNCTOR_COMPARE_(xy)
 
-  public:
-
-    typedef typename CK::Linear_kernel::Compare_x_2::result_type result_type;
-    using CK::Linear_kernel::Compare_x_2::operator();
-
-    result_type
-    operator() (const Circular_arc_point_2 &p0,
-                const Circular_arc_point_2 &p1) const
-    { return CircularFunctors::compare_x<CK>(p0, p1);}
-
-  };
-
-
-  template < class CK >
-  class Compare_y_2
-    : public CK::Linear_kernel::Compare_y_2
-  {
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-    typedef typename CK::Point_2 Point_2;
-
-  public:
-
-    typedef typename CK::Linear_kernel::Compare_y_2::result_type result_type;
-    using CK::Linear_kernel::Compare_y_2::operator();
-
-    result_type
-    operator() (const Circular_arc_point_2 &p0,
-                const Circular_arc_point_2 &p1) const
-    {return CircularFunctors::compare_y<CK>(p0, p1);}
-
-  };
-
-  template < class CK >
-  class Compare_xy_2
-    : public CK::Linear_kernel::Compare_xy_2
-  {
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
-    typedef typename CK::Point_2 Point_2;
-
-  public:
-
-    typedef typename CK::Linear_kernel::Compare_xy_2::result_type result_type;
-    using CK::Linear_kernel::Compare_xy_2::operator();
-
-    result_type
-    operator() (const Circular_arc_point_2 &p0,
-                const Circular_arc_point_2 &p1) const
-    { return CircularFunctors::compare_xy<CK>(p0, p1);}
-
-  };
+#undef CGAL_CIRCULAR_KERNEL_MACRO_FUNCTOR_COMPARE_
 
   template < class CK >
   class In_x_range_2
   {
+    typedef typename CK::Boolean                 Boolean;
     typedef typename CK::Circular_arc_2          Circular_arc_2;
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
+    typedef typename CK::Circular_arc_point_2    Circular_arc_point_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
 
   public:
-    typedef bool         result_type;
-
-    result_type
+    Boolean
     operator()(const Circular_arc_2 &a, const Circular_arc_point_2 &p) const
     { return CircularFunctors::point_in_x_range<CK>(a, p); }
 
-    result_type
+    Boolean
     operator()(const Line_arc_2 &a, const Circular_arc_point_2 &p) const
     { return CircularFunctors::point_in_x_range<CK>(a, p); }
-
   };
 
-
   template < class CK >
   class Has_on_2
-    : public CK::Linear_kernel::Has_on_2
+    // : public CK::Linear_kernel::Has_on_2
   {
+    typedef typename CK::Boolean                 Boolean;
     typedef typename CK::Circular_arc_2          Circular_arc_2;
     typedef typename CK::Circular_arc_point_2    Circular_arc_point_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
     typedef typename CK::Circle_2                Circle_2;
     typedef typename CK::Line_2                  Line_2;
 
+    typedef typename CK::Linear_kernel::Has_on_2 Linear_Has_on_2;
+
   public:
-          typedef typename CK::Linear_kernel::Has_on_2::result_type result_type;
+    // using CK::Linear_kernel::Has_on_2::operator();
 
-    using CK::Linear_kernel::Has_on_2::operator();
+    template <typename A, typename B>
+    Boolean
+    operator()(const A& a, const B& b) const
+    { return Linear_Has_on_2()(a, b); }
 
-    result_type
+    Boolean
     operator()(const Circle_2 &a, const Circular_arc_point_2 &p) const
     { return CircularFunctors::has_on<CK>(a, p); }
 
-    result_type
+    Boolean
     operator()(const Line_2 &a, const Circular_arc_point_2 &p) const
     { return LinearFunctors::has_on<CK>(a, p); }
 
-    result_type
+    Boolean
     operator()(const Circular_arc_2 &a, const Circular_arc_point_2 &p) const
     { return CircularFunctors::has_on<CK>(a, p); }
 
-    result_type
+    Boolean
     operator()(const Line_arc_2 &a, const Circular_arc_point_2 &p) const
     { return CircularFunctors::has_on<CK>(a, p); }
-
   };
 
   template < class CK >
   class Compare_y_to_right_2
   {
+    typedef typename CK::Comparison_result        Comparison_result;
     typedef typename CK::Circular_arc_2           Circular_arc_2;
-    typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
+    typedef typename CK::Circular_arc_point_2     Circular_arc_point_2;
     typedef typename CK::Line_arc_2               Line_arc_2;
 
   public:
-    typedef CGAL::Comparison_result result_type;
-
-    result_type
+    Comparison_result
     operator()(const Circular_arc_2 &a1,
                const Circular_arc_2 &a2,
                const Circular_arc_point_2 &p) const
     { return CircularFunctors::compare_y_to_right<CK>(a1, a2, p); }
 
-    result_type
+    Comparison_result
     operator()(const Line_arc_2 &a1,
                const Line_arc_2 &a2,
                const Circular_arc_point_2 &p) const
     { return CircularFunctors::compare_y_to_right<CK>(a1, a2, p); }
 
-    result_type
+    Comparison_result
     operator()(const Line_arc_2 &a1,
                const Circular_arc_2 &a2,
                const Circular_arc_point_2 &p) const
     { return CircularFunctors::compare_y_to_right<CK>(a1, a2, p); }
 
-    result_type
+    Comparison_result
     operator()(const Circular_arc_2 &a1,
                const Line_arc_2 &a2,
                const Circular_arc_point_2 &p) const
@@ -179,21 +146,16 @@ namespace CircularFunctors {
         return CGAL::SMALLER;
       return CGAL::LARGER;
     }
-
   };
 
   template < class CK >
   class Equal_2
-  : public CK::Linear_kernel::Equal_2
+    // : public CK::Linear_kernel::Equal_2
   {
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
+    typedef typename CK::Boolean                 Boolean;
+    typedef typename CK::Circular_arc_point_2    Circular_arc_point_2;
     typedef typename CK::Circular_arc_2          Circular_arc_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
-
-  public:
-    typedef typename  CK::Linear_kernel LK;
-    typedef typename LK::Equal_2 LK_Equal_2;
-
     typedef typename CK::Point_2 Point_2;
     typedef typename CK::Vector_2 Vector_2;
     typedef typename CK::Direction_2 Direction_2;
@@ -204,69 +166,78 @@ namespace CircularFunctors {
     typedef typename CK::Iso_rectangle_2 Iso_rectangle_2;
     typedef typename CK::Circle_2 Circle_2;
 
+    typedef typename  CK::Linear_kernel::Equal_2 Linear_Equal_2;
 
-    typedef typename CK::Linear_kernel::Equal_2::result_type result_type;
-    using CK::Linear_kernel::Equal_2::operator();
+  public:
+    // using CK::Linear_kernel::Equal_2::operator();
 
-    result_type
+    template <typename A, typename B>
+    Boolean
+    operator()(const A& a, const B& b) const {
+      return Linear_Equal_2()(a, b);
+    }
+
+    Boolean
     operator() (const Circular_arc_point_2 &p0,
                 const Circular_arc_point_2 &p1) const
     { return CircularFunctors::equal<CK>(p0, p1); }
 
-    result_type
+    Boolean
     operator() (const Circular_arc_2 &a0, const Circular_arc_2 &a1) const
     { return CircularFunctors::equal<CK>(a0, a1); }
 
-    result_type
+    Boolean
     operator() (const Line_arc_2 &a0, const Line_arc_2 &a1) const
     { return CircularFunctors::equal<CK>(a0, a1); }
-
    };
 
   template < class CK >
-  class Compare_y_at_x_2 : public CK::Linear_kernel::Compare_y_at_x_2
+  class Compare_y_at_x_2
+    // : public CK::Linear_kernel::Compare_y_at_x_2
   {
+    typedef typename CK::Comparison_result       Comparison_result;
     typedef typename CK::Circular_arc_2          Circular_arc_2;
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
+    typedef typename CK::Circular_arc_point_2    Circular_arc_point_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
 
+    typedef typename CK::Linear_kernel::Compare_y_at_x_2 Linear_Compare_y_at_x_2;
+
   public:
-    typedef typename CK::Linear_kernel::Compare_y_at_x_2::result_type   result_type;
+    // using CK::Linear_kernel::Compare_y_at_x_2::operator();
 
-    using CK::Linear_kernel::Compare_y_at_x_2::operator();
+    template <class... Args>
+    Comparison_result
+    operator()(const Args&... args) const
+    { return Linear_Compare_y_at_x_2()(args...); }
 
-    result_type
+    Comparison_result
     operator() (const Circular_arc_point_2 &p,
                 const Circular_arc_2 &A1) const
     { return CircularFunctors::compare_y_at_x<CK>(p, A1); }
 
-    result_type
+    Comparison_result
     operator() (const Circular_arc_point_2 &p,
                 const Line_arc_2 &A1) const
     { return CircularFunctors::compare_y_at_x<CK>(p, A1); }
-
   };
 
   template < class CK >
   class Do_overlap_2
   {
+    typedef typename CK::Boolean        Boolean;
     typedef typename CK::Circular_arc_2 Circular_arc_2;
     typedef typename CK::Line_arc_2     Line_arc_2;
 
   public:
-    typedef bool         result_type;
-
-    result_type
+    Boolean
     operator() (const Circular_arc_2 &A1, const Circular_arc_2 &A2) const
     { return CircularFunctors::do_overlap<CK>(A1, A2); }
 
-    result_type
+    Boolean
     operator() (const Line_arc_2 &A1, const Line_arc_2 &A2) const
     { return CircularFunctors::do_overlap<CK>(A1, A2); }
-
   };
 
-
   template < class CK >
   class Make_x_monotone_2
   {
@@ -274,9 +245,6 @@ namespace CircularFunctors {
     typedef typename CK::Line_arc_2 Line_arc_2;
 
   public:
-
-     typedef void         result_type;   //!!!
-
     template < class OutputIterator >
     OutputIterator
     operator()(const Circular_arc_2 &A, OutputIterator res) const
@@ -290,7 +258,6 @@ namespace CircularFunctors {
     {
       return CircularFunctors::make_x_monotone<CK>(A,res);
     }
-
   };
 
  template < class CK >
@@ -300,9 +267,6 @@ namespace CircularFunctors {
     typedef typename CK::Line_arc_2 Line_arc_2;
 
   public:
-
-     typedef void         result_type;   //!!!
-
     template < class OutputIterator >
     OutputIterator
     operator()(const Circular_arc_2 &A, OutputIterator res) const
@@ -326,19 +290,21 @@ namespace CircularFunctors {
     { *res++ = make_object(A);
       return res;
     }
-
   };
 
   template < class CK >
   class Do_intersect_2
-    : public CK::Linear_kernel::Do_intersect_2
+    // : public CK::Linear_kernel::Do_intersect_2
   {
+    typedef typename CK::Boolean                 Boolean;
+
+    typedef typename CK::Linear_kernel::Do_intersect_2 Linear_Do_intersect_2;
+
   public:
-    typedef typename CK::Linear_kernel::Do_intersect_2::result_type   result_type;
-    template <class T1, class T2>
-    result_type
-    operator()(const T1& t1, const T2& t2) const
-    { return Intersections::internal::do_intersect(t1, t2, CK()); }
+    template <typename A, typename B>
+    Boolean
+    operator()(const A& a, const B& b) const
+    { return Intersections::internal::do_intersect(a, b, CK()); }
   };
 
   template < class CK >
@@ -347,14 +313,12 @@ namespace CircularFunctors {
   //using the Lazy_kernel as linear kernel.
     //: public CK::Linear_kernel::Intersect_2
   {
-
     typedef typename CK::Circle_2                 Circle;
     typedef typename CK::Circular_arc_2           Circular_arc;
     typedef typename CK::Line_arc_2               Line_arc;
     typedef typename CK::Line_2                   Line;
 
     public:
-
     //using CK::Linear_kernel::Intersect_2::operator();
 
     template<class A, class B>
@@ -460,7 +424,6 @@ namespace CircularFunctors {
       *res++=typename CK::Linear_kernel::Intersect_2()(l1, l2);
       return res;
     }
-
   };
 
   template < class CK >
@@ -470,61 +433,61 @@ namespace CircularFunctors {
 
     typename CK::Polynomial_1_2
     operator() ( const typename CK::Line_2 & l )
-      {
-              return LinearFunctors::get_equation<CK>(l);
-      }
+    {
+      return LinearFunctors::get_equation<CK>(l);
+    }
 
     typename CK::Polynomial_for_circles_2_2
     operator() ( const typename CK::Circle_2 & c )
-      {
-        return CircularFunctors::get_equation<CK>(c);
-                  }
+    {
+      return CircularFunctors::get_equation<CK>(c);
+    }
   };
 
   template < class CK >
   class Split_2
   {
     typedef typename CK::Circular_arc_2          Circular_arc_2;
-    typedef typename CK::Circular_arc_point_2 Circular_arc_point_2;
+    typedef typename CK::Circular_arc_point_2    Circular_arc_point_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
 
   public:
-
-    typedef void         result_type;
-
-    result_type
+    void
     operator()(const Circular_arc_2 &A,
                const Circular_arc_point_2 &p,
                Circular_arc_2 &ca1, Circular_arc_2 &ca2) const
     { return CircularFunctors::split<CK>(A, p, ca1, ca2); }
 
-
-    result_type
+    void
     operator()(const Line_arc_2 &A,
                const Circular_arc_point_2 &p,
                Line_arc_2 &ca1, Line_arc_2 &ca2) const
     { return CircularFunctors::split<CK>(A, p, ca1, ca2); }
-
   };
 
   template < class CK >
   class Is_vertical_2
-    : public CK::Linear_kernel::Is_vertical_2
+    // : public CK::Linear_kernel::Is_vertical_2
   {
+    typedef typename CK::Boolean                 Boolean;
     typedef typename CK::Circular_arc_2          Circular_arc_2;
     typedef typename CK::Line_arc_2              Line_arc_2;
 
+    typedef typename CK::Linear_kernel::Is_vertical_2 Linear_Is_vertical_2;
+
   public:
+    // using CK::Linear_kernel::Is_vertical_2::operator();
 
-          typedef typename CK::Linear_kernel::Is_vertical_2::result_type result_type;
+    template <typename A>
+    Boolean
+    operator()(const A& a) const
+    { return Linear_Is_vertical_2()(a); }
 
-    using CK::Linear_kernel::Is_vertical_2::operator();
-
-    result_type
+    Boolean
     operator()(const Circular_arc_2 &A) const
     { return CircularFunctors::is_vertical<CK>(A); }
 
-    result_type
+    Boolean
     operator()(const Line_arc_2 &A) const
     { return CircularFunctors::is_vertical<CK>(A); }
 
@@ -533,56 +496,51 @@ namespace CircularFunctors {
   template < class CK >
   class Construct_circular_arc_2
   {
-
     typedef typename CK::FT                           FT;
-    typedef typename CK::RT                           RT;
     typedef typename CK::Point_2                      Point_2;
     typedef typename CK::Line_2                       Line_2;
     typedef typename CK::Circle_2                     Circle_2;
     typedef typename CK::Circular_arc_2               Circular_arc_2;
-    typedef typename CK::Kernel_base::Circular_arc_2  RCircular_arc_2;
     typedef typename Circular_arc_2::Rep              Rep;
     typedef typename CK::Circular_arc_point_2         Circular_arc_point_2;
 
   public:
-    typedef  Circular_arc_2 result_type;
-
-    result_type
+    Circular_arc_2
     operator()(void)
     { return Rep(); }
 
-    result_type
+    Circular_arc_2
     operator()(const Circle_2 &c) const
     { return Rep(c); }
 
-    result_type
+    Circular_arc_2
     operator()(const Circle_2 &support,
                const Circular_arc_point_2 &source,
                const Circular_arc_point_2 &target) const
     { return Rep(support,source,target); }
 
     // Not Documented
-    result_type
+    Circular_arc_2
     operator()(const Circle_2 &support,
                const Line_2 &l1, bool b1,
                const Line_2 &l2, bool b2) const
     { return Rep(support,l1,b1,l2,b2); }
 
     // Not Documented
-    result_type
+    Circular_arc_2
     operator()(const Circle_2 &c,
                const Circle_2 &c1, bool b_1,
                const Circle_2 &c2, bool b_2) const
     { return Rep(c,c1,b_1,c2,b_2); }
 
-    result_type
+    Circular_arc_2
     operator()(const Point_2 &begin,
                const Point_2 &middle,
                const Point_2 &end) const
     { return Rep(begin,middle,end); }
 
     // Not Documented
-    result_type
+    Circular_arc_2
     operator()(const Point_2 &begin,
                const Point_2 &end,
                const FT& bulge) const
@@ -600,47 +558,44 @@ namespace CircularFunctors {
     typedef typename CK::Circular_arc_point_2      Circular_arc_point_2;
     typedef typename CK::Segment_2                 Segment_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
-    typedef typename CK::Kernel_base::Line_arc_2   RLine_arc_2;
     typedef typename Line_arc_2::Rep               Rep;
 
   public:
-    typedef Line_arc_2   result_type;
-
-    result_type
+    Line_arc_2
     operator()(void)
     { return Rep(); }
 
     // Not Documented
-    result_type
+    Line_arc_2
     operator()(const Line_2 &support,
                const Circle_2 &c1,const bool b1,
                const Circle_2 &c2,const bool b2) const
     { return Rep(support,c1,b1,c2,b2); }
 
     // Not Documented
-    result_type
+    Line_arc_2
     operator()(const Line_2 &support,
                const Line_2 &l1,
                const Line_2 &l2) const
     { return Rep(support,l1,l2); }
 
-    result_type
+    Line_arc_2
     operator()(const Line_2 &support,
                const Circular_arc_point_2 &p1,
                const Circular_arc_point_2 &p2) const
     { return Rep(support,p1,p2); }
 
-//     result_type
+//     Line_arc_2
 //     operator()(const Line_2 &support,
 //                const Point_2 &p1,
 //                const Point_2 &p2) const
 //     { return Rep(support,p1,p2); }
 
-    result_type
+    Line_arc_2
     operator()(const Segment_2 &s) const
     { return Rep(s); }
 
-    result_type
+    Line_arc_2
     operator()(const Point_2 &p1,
                const Point_2 &p2) const
     { return Rep(p1,p2); }
@@ -652,40 +607,32 @@ namespace CircularFunctors {
   {
     typedef typename CK::Point_2               Point_2;
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
-    typedef typename CK::Kernel_base::Circular_arc_point_2
-                                               RCircular_arc_point_2;
     typedef typename Circular_arc_point_2::Rep Rep;
     typedef typename Circular_arc_point_2::Root_for_circles_2_2
                                                Root_for_circles_2_2;
 
   public:
-    typedef Circular_arc_point_2 result_type;
-
-    result_type
+    Circular_arc_point_2
     operator()(void)
     { return Rep(); }
 
-    result_type
+    Circular_arc_point_2
     operator()(const Root_for_circles_2_2 & np) const
     { return Rep(np); }
 
-    result_type
+    Circular_arc_point_2
     operator()(const Point_2 & p) const
     { return Rep(p); }
 
   };
 
-
   template <class CK>
   class Compute_circular_x_2
   {
     typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
-    typedef typename CK::Root_of_2                 Root_of_2;
 
   public:
-    typedef const Root_of_2&            result_type;
-
-    result_type operator() (const Circular_arc_point_2 & a) const
+    decltype(auto) operator() (const Circular_arc_point_2 & a) const
     {
       return (a.rep().x());
     }
@@ -696,13 +643,9 @@ namespace CircularFunctors {
   class Compute_circular_y_2
   {
     typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
-    typedef typename CK::Root_of_2                 Root_of_2;
 
   public:
-
-    typedef const Root_of_2&            result_type;
-
-    result_type operator() (const Circular_arc_point_2 & a) const
+    decltype(auto) operator() (const Circular_arc_point_2 & a) const
     {
       return (a.rep().y());
     }
@@ -714,17 +657,14 @@ namespace CircularFunctors {
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
-    typedef typename CK::Circular_arc_point_2      Circular_arc_point_2;
 
   public:
-    typedef const Circular_arc_point_2 &  result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    decltype(auto) operator() (const Circular_arc_2& a) const
     {
       return (a.rep().left());
     }
 
-    result_type operator() (const Line_arc_2 & a) const
+    decltype(auto) operator() (const Line_arc_2& a) const
     {
       return (a.rep().left());
     }
@@ -736,18 +676,14 @@ namespace CircularFunctors {
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
-    typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
 
   public:
-
-    typedef const Circular_arc_point_2& result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    decltype(auto) operator() (const Circular_arc_2& a) const
     {
       return (a.rep().right());
     }
 
-    result_type operator() (const Line_arc_2 & a) const
+    decltype(auto) operator() (const Line_arc_2& a) const
     {
       return (a.rep().right());
     }
@@ -759,16 +695,12 @@ namespace CircularFunctors {
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
-    typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
 
   public:
-
-    typedef const Circular_arc_point_2& result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    decltype(auto) operator() (const Circular_arc_2& a) const
     { return a.rep().source(); }
 
-    result_type operator() (const Line_arc_2 & a) const
+    decltype(auto) operator() (const Line_arc_2& a) const
     { return a.rep().source();}
 
   };
@@ -779,16 +711,12 @@ namespace CircularFunctors {
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
-    typedef typename CK::Circular_arc_point_2   Circular_arc_point_2;
 
   public:
-
-    typedef const Circular_arc_point_2& result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    decltype(auto) operator() (const Circular_arc_2& a) const
     { return a.rep().target();}
 
-    result_type operator() (const Line_arc_2 & a) const
+    decltype(auto) operator() (const Line_arc_2& a) const
     { return a.rep().target();}
 
   };
@@ -796,19 +724,17 @@ namespace CircularFunctors {
   template <class CK>
   class Is_x_monotone_2
   {
+    typedef typename CK::Boolean                   Boolean;
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
 
   public:
-
-    typedef bool         result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    Boolean operator() (const Circular_arc_2 & a) const
     {
       return (a.rep().is_x_monotone());
     }
 
-    result_type operator() (const Line_arc_2 & a) const
+    Boolean operator() (const Line_arc_2 & a) const
     {
       return (a.rep().is_x_monotone());
     }
@@ -818,19 +744,17 @@ namespace CircularFunctors {
   template <class CK>
   class Is_y_monotone_2
   {
+    typedef typename CK::Boolean                   Boolean;
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
 
   public:
-
-    typedef bool         result_type;
-
-    result_type operator() (const Circular_arc_2 & a) const
+    Boolean operator() (const Circular_arc_2& a) const
     {
       return (a.rep().is_y_monotone());
     }
 
-    result_type operator() (const Line_arc_2 & a) const
+    Boolean operator() (const Line_arc_2& a) const
     {
       return (a.rep().is_y_monotone());
     }
@@ -839,48 +763,58 @@ namespace CircularFunctors {
 
   template <class CK>
   class Construct_bbox_2
-    : public CK::Linear_kernel::Construct_bbox_2
+    // : public CK::Linear_kernel::Construct_bbox_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
     typedef typename CK::Circular_arc_point_2      Circular_arc_point_2;
     typedef typename CK::Line_arc_2                Line_arc_2;
     typedef typename CK::Circle_2                  Circle_2;
 
+    typedef typename CK::Linear_kernel::Construct_bbox_2 Linear_Construct_bbox_2;
+
   public:
+    // using CK::Linear_kernel::Construct_bbox_2::operator();
 
-    typedef typename CK::Linear_kernel::Construct_bbox_2::result_type result_type;
-    using CK::Linear_kernel::Construct_bbox_2::operator();
+    template <typename A>
+    decltype(auto)
+    operator()(const A& a) const
+    { return Linear_Construct_bbox_2()(a); }
 
-    result_type operator() (const Circular_arc_point_2 & a) const
+    decltype(auto) operator() (const Circular_arc_point_2& a) const
     {
       return a.rep().bbox();
     }
 
-    result_type operator() (const Circular_arc_2 & a) const
+    decltype(auto) operator() (const Circular_arc_2& a) const
     {
       return a.rep().bbox();
     }
 
-    result_type operator() (const Line_arc_2 & a) const
+    decltype(auto) operator() (const Line_arc_2& a) const
     {
       return a.rep().bbox();
     }
-
   };
 
   template <class CK>
   class Bounded_side_2
-    : public CK::Linear_kernel::Bounded_side_2
+    // : public CK::Linear_kernel::Bounded_side_2
   {
+    typedef typename CK::Bounded_side          Bounded_side;
     typedef typename CK::Circle_2              Circle_2;
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
 
+    typedef typename CK::Linear_kernel::Bounded_side_2 Linear_Bounded_side_2;
+
   public:
-    typedef typename CK::Linear_kernel::Bounded_side_2::result_type result_type;
+    // using CK::Linear_kernel::Bounded_side_2::operator();
 
-    using CK::Linear_kernel::Bounded_side_2::operator();
+    template <typename A, typename B>
+    Bounded_side
+    operator()(const A& a, const B& b) const
+    { return Linear_Bounded_side_2()(a, b); }
 
-    result_type
+    Bounded_side
     operator()(const Circle_2& c, const Circular_arc_point_2& p) const
     { return CircularFunctors::bounded_side<CK>(c,p); }
 
@@ -888,17 +822,23 @@ namespace CircularFunctors {
 
   template <class CK>
   class Has_on_bounded_side_2
-    : public CK::Linear_kernel::Has_on_bounded_side_2
+    // : public CK::Linear_kernel::Has_on_bounded_side_2
   {
+    typedef typename CK::Boolean               Boolean;
     typedef typename CK::Circle_2              Circle_2;
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
 
+    typedef typename CK::Linear_kernel::Has_on_bounded_side_2 Linear_Has_on_bounded_side_2;
+
   public:
-    typedef typename CK::Linear_kernel::Has_on_bounded_side_2::result_type result_type;
+    // using CK::Linear_kernel::Has_on_bounded_side_2::operator();
 
-    using CK::Linear_kernel::Has_on_bounded_side_2::operator();
+    template <typename A, typename B>
+    Boolean
+    operator()(const A& a, const B& b) const
+    { return Linear_Has_on_bounded_side_2()(a, b); }
 
-    result_type
+    Boolean
     operator()(const Circle_2& c, const Circular_arc_point_2& p) const
     { return CK().bounded_side_2_object()(c,p) == ON_BOUNDED_SIDE; }
 
@@ -906,20 +846,25 @@ namespace CircularFunctors {
 
   template <class CK>
   class Has_on_unbounded_side_2
-    : public CK::Linear_kernel::Has_on_unbounded_side_2
+    // : public CK::Linear_kernel::Has_on_unbounded_side_2
   {
+    typedef typename CK::Boolean               Boolean;
     typedef typename CK::Circle_2              Circle_2;
     typedef typename CK::Circular_arc_point_2  Circular_arc_point_2;
 
+    typedef typename CK::Linear_kernel::Has_on_unbounded_side_2 Linear_Has_on_unbounded_side_2;
+
   public:
-    typedef typename CK::Linear_kernel::Has_on_unbounded_side_2::result_type result_type;
+    // using CK::Linear_kernel::Has_on_unbounded_side_2::operator();
 
-    using CK::Linear_kernel::Has_on_unbounded_side_2::operator();
+    template <typename A, typename B>
+    Boolean
+    operator()(const A& a, const B& b) const
+    { return Linear_Has_on_unbounded_side_2()(a, b); }
 
-    result_type
+    Boolean
     operator()(const Circle_2& c, const Circular_arc_point_2& p) const
     { return CK().bounded_side_2_object()(c,p) == ON_UNBOUNDED_SIDE; }
-
   };
 
 #ifndef CGAL_NO_DEPRECATED_CODE
@@ -927,31 +872,21 @@ namespace CircularFunctors {
   class Construct_supporting_circle_2
   {
     typedef typename CK::Circular_arc_2            Circular_arc_2;
-    typedef typename CK::Circle_2                  Circle_2;
 
   public:
-
-    typedef Circle_2             result_type;
-
-    CGAL_DEPRECATED result_type operator() (const Circular_arc_2 & a) const
+    CGAL_DEPRECATED decltype(auto) operator() (const Circular_arc_2 & a) const
     {
       return a.rep().supporting_circle();
     }
   };
 
-
   template <class CK>
   class Construct_supporting_line_2
   {
     typedef typename CK::Line_arc_2            Line_arc_2;
-    typedef typename CK::Line_2                Line_2;
-    typedef typename CK::Circle_2              Circle_2;
 
   public:
-
-    typedef Line_2               result_type;
-
-    CGAL_DEPRECATED result_type operator() (const Line_arc_2 & a) const
+    CGAL_DEPRECATED decltype(auto) operator() (const Line_arc_2 & a) const
     {
       return a.rep().supporting_line();
     }
@@ -960,24 +895,28 @@ namespace CircularFunctors {
 
   template <typename CK>
   class Construct_center_2
-            : public CK::Linear_kernel::Construct_center_2
+    // : public CK::Linear_kernel::Construct_center_2
   {
     typedef typename CK::Circular_arc_2  Circular_arc_2;
-  public:
-    typedef typename CK::Linear_kernel::Construct_center_2::result_type result_type;
-   using CK::Linear_kernel::Construct_center_2::operator();
 
-    result_type
+    typedef typename CK::Linear_kernel::Construct_center_2 Linear_Construct_center_2;
+
+  public:
+    // using CK::Linear_kernel::Construct_center_2::operator();
+
+    template <typename A>
+    decltype(auto)
+    operator()(const A& a) const
+    { return Linear_Construct_center_2()(a); }
+
+    decltype(auto)
     operator()(const Circular_arc_2& c) const
     { return c.rep().center(); }
-
   };
 
   template <typename CK>
   class Compute_squared_radius_2
   {
-
-  private:
     typedef typename CK::Circular_arc_2  Circular_arc_2;
     typedef typename CK::Linear_kernel LK;
     typedef typename LK::Compute_squared_radius_2 LK_Compute_squared_radius_2;
