@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/STL_Extension/include/CGAL/Concurrent_compact_container.h $
-// $Id: include/CGAL/Concurrent_compact_container.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/STL_Extension/include/CGAL/Concurrent_compact_container.h $
+// $Id: include/CGAL/Concurrent_compact_container.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Clement Jamin
@@ -109,12 +109,6 @@ namespace CCC_internal {
       e.set_erase_counter(c);
     }
 
-    template <typename Element>
-    static void set_erase_counter(Element* e, unsigned int c)
-    {
-      e->set_erase_counter(c);
-    }
-
     template <typename Element>
     static void restore_erase_counter(Element* e, unsigned int c)
     {
@@ -222,6 +216,9 @@ class Concurrent_compact_container
   typedef Concurrent_compact_container <T, Al>                      Self;
   typedef Concurrent_compact_container_traits <T>                   Traits;
 
+  template <typename U> using EraseCounterStrategy =
+      internal::Erase_counter_strategy<internal::has_increment_erase_counter<U>::value>;
+
 public:
   typedef CGAL::Time_stamper_impl<T>                Time_stamper;
   typedef Time_stamper                              Time_stamper_impl; // backward compatibility
@@ -364,28 +361,22 @@ public:
   // (just forward the arguments to the constructor, to optimize a copy).
   template < typename... Args >
   iterator
-  emplace(const Args&... args)
+  emplace(Args&&... args)
   {
-    typedef CCC_internal::Erase_counter_strategy<
-      CCC_internal::has_increment_erase_counter<T>::value> EraseCounterStrategy;
     FreeList * fl = get_free_list();
     pointer ret = init_insert(fl);
-    auto erase_counter = EraseCounterStrategy::erase_counter(*ret);
-    new (ret) value_type(args...);
-    EraseCounterStrategy::set_erase_counter(*ret, erase_counter);
+    {
+      internal::Time_stamp_and_erase_counter_backup_and_restore_guard<T, Time_stamper>
+          guard(ret);
+      new (ret) value_type(std::forward<Args>(args)...);
+    }
     return finalize_insert(ret, fl);
   }
 
-  iterator insert(const T &t)
+  template <typename U>
+  iterator insert(U&& u)
   {
-    typedef CCC_internal::Erase_counter_strategy<
-      CCC_internal::has_increment_erase_counter<T>::value> EraseCounterStrategy;
-    FreeList * fl = get_free_list();
-    pointer ret = init_insert(fl);
-    auto erase_counter = EraseCounterStrategy::erase_counter(*ret);;
-    std::allocator_traits<allocator_type>::construct(m_alloc, ret, t);
-    EraseCounterStrategy::set_erase_counter(*ret, erase_counter);
-    return finalize_insert(ret, fl);
+    return emplace(std::forward<U>(u));
   }
 
   template < class InputIterator >
@@ -405,16 +396,18 @@ public:
 private:
   void erase(iterator x, FreeList * fl)
   {
-    typedef CCC_internal::Erase_counter_strategy<
-      CCC_internal::has_increment_erase_counter<T>::value> EraseCounterStrategy;
-
-    CGAL_precondition(type(x) == USED);
-    EraseCounterStrategy::increment_erase_counter(*x);
-    auto erase_counter = EraseCounterStrategy::erase_counter(*x);
     auto ptr = &*x;
-    std::allocator_traits<allocator_type>::destroy(m_alloc, &*x);
-    EraseCounterStrategy::set_erase_counter(ptr, erase_counter);
-    put_on_free_list(&*x, fl);
+    CGAL_precondition(type(x) == USED);
+    EraseCounterStrategy<T>::increment_erase_counter(*x);
+    {
+      internal::Time_stamp_and_erase_counter_backup_and_restore_guard<T, Time_stamper>
+          guard(ptr);
+
+      std::allocator_traits<allocator_type>::destroy(m_alloc, ptr);
+    }
+
+
+    put_on_free_list(ptr, fl);
   }
 public:
 
@@ -799,9 +792,6 @@ template < class T, class Allocator >
 void Concurrent_compact_container<T, Allocator>::
   allocate_new_block(FreeList * fl)
 {
-  typedef CCC_internal::Erase_counter_strategy<
-    CCC_internal::has_increment_erase_counter<T>::value> EraseCounterStrategy;
-
   size_type old_block_size;
   pointer new_block;
 
@@ -839,7 +829,7 @@ void Concurrent_compact_container<T, Allocator>::
   // will correspond to the iterator order...
   for (size_type i = old_block_size; i >= 1; --i)
   {
-    EraseCounterStrategy::set_erase_counter(*(new_block + i), 0);
+    EraseCounterStrategy<T>::set_erase_counter(*(new_block + i), 0);
     Time_stamper::initialize_time_stamp(new_block + i);
     put_on_free_list(new_block + i, fl);
   }
