@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Coplanar_3.h $
-// $Id: include/CGAL/Filtered_kernel/internal/Static_filters/Coplanar_3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Filtered_kernel/include/CGAL/Filtered_kernel/internal/Static_filters/Coplanar_3.h $
+// $Id: include/CGAL/Filtered_kernel/internal/Static_filters/Coplanar_3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -25,17 +25,14 @@ template < typename K_base, typename SFK >
 class Coplanar_3
   : public K_base::Coplanar_3
 {
-  typedef typename K_base::Point_3 Point_3;
+  typedef typename K_base::Boolean    Boolean;
+  typedef typename K_base::Point_3    Point_3;
+
   typedef typename K_base::Coplanar_3 Base;
   typedef typename SFK::Orientation_3 Orientation_3;
 
 public:
-
-  typedef typename Base::result_type  result_type;
-
-
-
-  result_type
+  Boolean
   operator()(const Point_3& p,const Point_3& q, const Point_3& r, const Point_3& s) const
   {
     return Orientation_3()(p,q,r,s) == COPLANAR;
