@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/STL_Extension/include/CGAL/Has_timestamp.h $
-// $Id: include/CGAL/Has_timestamp.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/STL_Extension/include/CGAL/Has_timestamp.h $
+// $Id: include/CGAL/Has_timestamp.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Jane Tournois
@@ -36,6 +36,9 @@ namespace internal {
     // when T does not have a Has_timestamp tag
   {};
 
+  template <typename T>
+  constexpr bool has_timestamp_v = Has_timestamp<T>::value;
+
 } // end namespace internal
 } // end namespace CGAL
 
