@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Homogeneous_kernel/include/CGAL/Homogeneous/LineH2.h $
-// $Id: include/CGAL/Homogeneous/LineH2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Homogeneous_kernel/include/CGAL/Homogeneous/LineH2.h $
+// $Id: include/CGAL/Homogeneous/LineH2.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -47,8 +47,8 @@ public:
     LineH2(const RT& a, const RT& b, const RT& c)
       : base{a, b, c} {}
 
-    bool           operator==(const LineH2<R>& l) const;
-    bool           operator!=(const LineH2<R>& l) const;
+    typename R_::Boolean operator==(const LineH2<R>& l) const;
+    typename R_::Boolean operator!=(const LineH2<R>& l) const;
 
     const RT &     a() const { return get_pointee_or_identity(base)[0]; }
     const RT &     b() const { return get_pointee_or_identity(base)[1]; }
@@ -58,7 +58,7 @@ public:
 
 template < class R >
 CGAL_KERNEL_MEDIUM_INLINE
-bool
+typename R::Boolean
 LineH2<R>::operator==(const LineH2<R>& l) const
 {
   if (  (a() * l.c() != l.a() * c() )
@@ -83,7 +83,7 @@ LineH2<R>::operator==(const LineH2<R>& l) const
 
 template < class R >
 inline
-bool
+typename R::Boolean
 LineH2<R>::operator!=(const LineH2<R>& l) const
 { return !(*this == l); }
 
