@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Kinetic_space_partition/include/CGAL/Kinetic_space_partition_3.h $
-// $Id: include/CGAL/Kinetic_space_partition_3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Kinetic_space_partition/include/CGAL/Kinetic_space_partition_3.h $
+// $Id: include/CGAL/Kinetic_space_partition_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -29,7 +29,6 @@
 #include <CGAL/Real_timer.h>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
 #include <CGAL/Constrained_triangulation_plus_2.h>
-#include <CGAL/Base_with_time_stamp.h>
 #include <CGAL/Triangulation_vertex_base_with_info_2.h>
 #include <CGAL/Triangulation_face_base_with_info_2.h>
 
@@ -398,6 +397,8 @@ public:
     using NP_helper = Point_set_processing_3_np_helper<PointRange, NamedParameters>;
     using PointMap = typename NP_helper::Point_map;
 
+    static_assert(std::is_same_v<typename NP_helper::Geom_traits, Kernel>);
+
     PointMap point_map = NP_helper::get_point_map(np);
 
     To_exact to_exact;
@@ -501,8 +502,8 @@ public:
     for (auto p : m_input2regularized)
       n.insert(p);
 
-    assert(m_regularized2input.size() == m_input_polygons.size());
-    assert(m_regularized2input.size() == n.size());
+    CGAL_assertion(m_regularized2input.size() == m_input_polygons.size());
+    CGAL_assertion(m_regularized2input.size() == n.size());
 
     if (m_parameters.bbox_dilation_ratio < FT(1)) {
       CGAL_warning_msg(m_parameters.bbox_dilation_ratio >= FT(1),
@@ -965,7 +966,7 @@ public:
           lcc.template info<2>(face_dart).plane = m_partition_nodes[faces_of_volume[j].first].m_data->support_plane(m_partition_nodes[faces_of_volume[j].first].m_data->face_to_support_plane()[faces_of_volume[j].second]).exact_plane();
         }
         else {
-          assert(lcc.template info<2>(face_dart).part_of_initial_polygon == m_partition_nodes[faces_of_volume[j].first].m_data->face_is_part_of_input_polygon()[faces_of_volume[j].second]);
+          CGAL_assertion(lcc.template info<2>(face_dart).part_of_initial_polygon == m_partition_nodes[faces_of_volume[j].first].m_data->face_is_part_of_input_polygon()[faces_of_volume[j].second]);
         }
 
         vtx_of_face.clear();
@@ -1033,7 +1034,7 @@ private:
   };
 
   const Point_3& volume_centroid(std::size_t volume_index) const {
-    assert(volume_index < m_volumes.size());
+    CGAL_assertion(volume_index < m_volumes.size());
     auto p = m_volumes[volume_index];
     return m_partition_nodes[p.first].m_data->volumes()[p.second].centroid;
   }
@@ -1140,7 +1141,7 @@ private:
   template<class OutputIterator>
   void faces_of_input_polygon(const std::size_t polygon_index, OutputIterator it) const {
     if (polygon_index >= m_input_planes.size()) {
-      assert(false);
+      CGAL_assertion(false);
     }
 
     for (std::size_t idx : m_partitions) {
@@ -1195,14 +1196,14 @@ private:
     const auto &p = m_partition_nodes[face_index.first].face_neighbors[face_index.second];
     if (p.second.second >= std::size_t(-6)) { // Faces on the boundary box are neighbors with an infinite outside volume
       auto it = m_index2volume.find(p.first);
-      assert(it != m_index2volume.end());
+      CGAL_assertion(it != m_index2volume.end());
       return std::pair<int, int>(static_cast<int>(it->second), static_cast<int>(p.second.second));
     }
     else {
       auto it1 = m_index2volume.find(p.first);
-      assert(it1 != m_index2volume.end());
+      CGAL_assertion(it1 != m_index2volume.end());
       auto it2 = m_index2volume.find(p.second);
-      assert(it2 != m_index2volume.end());
+      CGAL_assertion(it2 != m_index2volume.end());
       return std::pair<int, int>(static_cast<int>(it1->second), static_cast<int>(it2->second));
     }
   }
@@ -1293,8 +1294,8 @@ private:
         }
 
         vertices.back()->info().idA2 = pts_idx[f][v];
-        assert(pts_idx[f][v].first != static_cast<std::size_t>(-1));
-        assert(pts_idx[f][v].second != static_cast<std::size_t>(-1));
+        CGAL_assertion(pts_idx[f][v].first != static_cast<std::size_t>(-1));
+        CGAL_assertion(pts_idx[f][v].second != static_cast<std::size_t>(-1));
         vertices.back()->info().adjacent.insert(faces[f]);
         vertices.back()->info().set_point(pts[f][v]);
         face2vtx[pts_idx[f][v]] = vertices.size() - 1;
@@ -1810,7 +1811,7 @@ private:
 
       for (std::size_t j = 0; j < vtx.size(); j++) {
         auto it = vtx2index.find(vtx[j]);
-        assert(it != vtx2index.end());
+        CGAL_assertion(it != vtx2index.end());
         if (vertices_of_volume.find(vtx[j]) == vertices_of_volume.end() && added_vertices[it->second])
           return false;
       }
@@ -1877,7 +1878,7 @@ private:
     From_exact from_exact;
     auto pair = replaced.insert(f);
     std::size_t idx;
-    assert(m_partition_nodes[f.first].face_neighbors[f.second].first.first == f.first);
+    CGAL_assertion(m_partition_nodes[f.first].face_neighbors[f.second].first.first == f.first);
     std::size_t vol_idx = m_partition_nodes[f.first].face_neighbors[f.second].first.second;
 
     if (!pair.second) {
@@ -1895,11 +1896,11 @@ private:
     else {
       idx = f.second;
       // All boundary faces should have a negative second neighbor.
-      assert(m_partition_nodes[f.first].face_neighbors[idx].second.second >= std::size_t(-6));
+      CGAL_assertion(m_partition_nodes[f.first].face_neighbors[idx].second.second >= std::size_t(-6));
     }
     std::vector<Index>& vertices = m_partition_nodes[f.first].face2vertices[idx];
     // First neighbor of other face should point to the inside volume in the other partition and thus cannot be negative
-    assert(m_partition_nodes[other.first].face_neighbors[other.second].first.second < std::size_t(-6));
+    CGAL_assertion(m_partition_nodes[other.first].face_neighbors[other.second].first.second < std::size_t(-6));
     m_partition_nodes[f.first].face_neighbors[idx].second = m_partition_nodes[other.first].face_neighbors[other.second].first;
     vertices.resize(polygon.size());
     for (std::size_t i = 0; i < polygon.size(); i++) {
@@ -1966,7 +1967,7 @@ private:
           auto eit = cdt.incident_edges(face.back(), last);
           auto first = eit;
 
-          assert(!cdt.is_infinite(eit->first));
+          CGAL_assertion(!cdt.is_infinite(eit->first));
           do {
             // Export tri
 
@@ -1989,7 +1990,7 @@ private:
               break;
             }
             eit++;
-            assert(eit != first);
+            CGAL_assertion(eit != first);
           } while (eit != first);
           // If last vertex is equal to first vertex, stop
           // Take last vertex and face
@@ -1997,7 +1998,7 @@ private:
           // Check if opposite face of next edge, if not same, add next vertex and reloop
           // if not, check next face
 
-          assert(face.size() < 100);
+          CGAL_assertion(face.size() < 100);
         }
 
         // The last vertex is equal to the first one, so it should be removed.
@@ -2093,7 +2094,7 @@ private:
 
         // Check length of constraint
         // size 2 means it has not been split, thus there are no t-junctions.
-        assert (vertices_of_edge.size() >= 2);
+        CGAL_assertion(vertices_of_edge.size() >= 2);
 
         faces_of_volume.clear();
         faces(volume, std::back_inserter(faces_of_volume));
