@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Number_types/include/CGAL/MP_Float.h $
-// $Id: MP_Float.h 45b5fd4 2022-07-06T12:58:49+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Number_types/include/CGAL/MP_Float.h $
+// $Id: include/CGAL/MP_Float.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -167,7 +167,7 @@ public:
     low = static_cast<limb>(l & mask); //extract low bits from l
     high= static_cast<limb>((l - low) >> sizeof_limb); //extract high bits from l
 
-    CGAL_postcondition ( l == low + ( static_cast<limb2>(high) << sizeof_limb ) );
+    CGAL_postcondition ( l == low + ( high * (limb2(1) << sizeof_limb) ) );
   }
 
   // Given a limb2, returns the higher limb.
@@ -324,7 +324,7 @@ public:
     return exp + exponent_type(v.size());
   }
 
-  // Rescale the value by some factor (in limbs).  (substract the exponent)
+  // Rescale the value by some factor (in limbs).  (subtract the exponent)
   void rescale(exponent_type scale)
   {
     if (v.size() != 0)
@@ -617,7 +617,7 @@ division(const MP_Float & n, const MP_Float & d)
 
   CGAL_precondition(divisor != 0);
 
-  // Rescale d to have a to_double() value with reasonnable exponent.
+  // Rescale d to have a to_double() value with reasonable exponent.
   exponent_type scale_d = divisor.find_scale();
   divisor.rescale(scale_d);
   const double dd = INTERN_MP_FLOAT::to_double(divisor);
