@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Point_set_3/include/CGAL/Point_set_3/IO/LAS.h $
-// $Id: include/CGAL/Point_set_3/IO/LAS.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Point_set_3/include/CGAL/Point_set_3/IO/LAS.h $
+// $Id: include/CGAL/Point_set_3/IO/LAS.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Simon Giraudot
@@ -219,86 +219,86 @@ bool write_LAS(std::ostream& os,
 
   Ushort_map intensity;
   bool remove_intensity;
-  boost::tie(intensity, remove_intensity)
+  std::tie(intensity, remove_intensity)
       = point_set.template add_property_map<unsigned short>("intensity", 0);
 
   Uchar_map return_number;
   bool remove_return_number;
-  boost::tie(return_number, remove_return_number)
+  std::tie(return_number, remove_return_number)
       = point_set.template add_property_map<unsigned char>("return_number", 0);
 
   Uchar_map number_of_returns;
   bool remove_number_of_returns;
-  boost::tie(number_of_returns, remove_number_of_returns)
+  std::tie(number_of_returns, remove_number_of_returns)
       = point_set.template add_property_map<unsigned char>("number_of_returns", 0);
 
   Uchar_map scan_direction_flag;
   bool remove_scan_direction_flag;
-  boost::tie(scan_direction_flag, remove_scan_direction_flag)
+  std::tie(scan_direction_flag, remove_scan_direction_flag)
       = point_set.template add_property_map<unsigned char>("scan_direction_flag", 0);
 
   Uchar_map edge_of_flight_line;
   bool remove_edge_of_flight_line;
-  boost::tie(edge_of_flight_line, remove_edge_of_flight_line)
+  std::tie(edge_of_flight_line, remove_edge_of_flight_line)
       = point_set.template add_property_map<unsigned char>("edge_of_flight_line", 0);
 
   Uchar_map classification;
   bool remove_classification;
-  boost::tie(classification, remove_classification)
+  std::tie(classification, remove_classification)
       = point_set.template add_property_map<unsigned char>("classification", 0);
 
   Uchar_map synthetic_flag;
   bool remove_synthetic_flag;
-  boost::tie(synthetic_flag, remove_synthetic_flag)
+  std::tie(synthetic_flag, remove_synthetic_flag)
       = point_set.template add_property_map<unsigned char>("synthetic_flag", 0);
 
   Uchar_map keypoint_flag;
   bool remove_keypoint_flag;
-  boost::tie(keypoint_flag, remove_keypoint_flag)
+  std::tie(keypoint_flag, remove_keypoint_flag)
       = point_set.template add_property_map<unsigned char>("keypoint_flag", 0);
 
   Uchar_map withheld_flag;
   bool remove_withheld_flag;
-  boost::tie(withheld_flag, remove_withheld_flag)
+  std::tie(withheld_flag, remove_withheld_flag)
       = point_set.template add_property_map<unsigned char>("withheld_flag", 0);
 
   Float_map scan_angle;
   bool remove_scan_angle;
-  boost::tie(scan_angle, remove_scan_angle)
+  std::tie(scan_angle, remove_scan_angle)
       = point_set.template add_property_map<float>("scan_angle", 0.);
 
   Uchar_map user_data;
   bool remove_user_data;
-  boost::tie(user_data, remove_user_data)
+  std::tie(user_data, remove_user_data)
       = point_set.template add_property_map<unsigned char>("user_data", 0);
 
   Ushort_map point_source_ID;
   bool remove_point_source_ID;
-  boost::tie(point_source_ID, remove_point_source_ID)
+  std::tie(point_source_ID, remove_point_source_ID)
       = point_set.template add_property_map<unsigned short>("point_source_ID", 0);
 
   Uint_map deleted_flag;
   bool remove_deleted_flag;
-  boost::tie(deleted_flag, remove_deleted_flag)
+  std::tie(deleted_flag, remove_deleted_flag)
       = point_set.template add_property_map<unsigned int>("deleted_flag", 0);
 
   Double_map gps_time;
   bool remove_gps_time;
-  boost::tie(gps_time, remove_gps_time)
+  std::tie(gps_time, remove_gps_time)
       = point_set.template add_property_map<double>("gps_time", 0);
 
   Ushort_map R;
   bool remove_R;
-  boost::tie(R, remove_R) = point_set.template add_property_map<unsigned short>("R", 0);
+  std::tie(R, remove_R) = point_set.template add_property_map<unsigned short>("R", 0);
   Ushort_map G;
   bool remove_G;
-  boost::tie(G, remove_G) = point_set.template add_property_map<unsigned short>("G", 0);
+  std::tie(G, remove_G) = point_set.template add_property_map<unsigned short>("G", 0);
   Ushort_map B;
   bool remove_B;
-  boost::tie(B, remove_B) = point_set.template add_property_map<unsigned short>("B", 0);
+  std::tie(B, remove_B) = point_set.template add_property_map<unsigned short>("B", 0);
   Ushort_map I;
   bool remove_I;
-  boost::tie(I, remove_I) = point_set.template add_property_map<unsigned short>("I", 0);
+  std::tie(I, remove_I) = point_set.template add_property_map<unsigned short>("I", 0);
 
   if(remove_R)
   {
