@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Polygon/include/CGAL/Polygon_2.h $
-// $Id: include/CGAL/Polygon_2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Polygon/include/CGAL/Polygon_2.h $
+// $Id: include/CGAL/Polygon_2.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -60,8 +60,8 @@ namespace CGAL {
 /// algorithms were used and what complexity they have.
 ///
 
-template <class Traits_P, class Container_P
-        = std::vector<typename Traits_P::Point_2> >
+template <class Traits_, class Container_
+        = std::vector<typename Traits_::Point_2> >
 class Polygon_2 {
 
   public:
@@ -70,33 +70,33 @@ class Polygon_2 {
     /// @{
 
     /// The traits type.
-    typedef Traits_P Traits;
+    typedef Traits_ Traits;
     /// The container type.
-    typedef Container_P Container;
+    typedef Container_ Container;
 
     /// The number type of the coordinates of the points of the polygon.
-    typedef typename Traits_P::FT FT;
+    typedef typename Traits_::FT FT;
     /// The point type of the polygon.
-    typedef typename Traits_P::Point_2 Point_2;
+    typedef typename Traits_::Point_2 Point_2;
     /// The type of a segment between two points of the polygon.
-    typedef typename Traits_P::Segment_2 Segment_2;
+    typedef typename Traits_::Segment_2 Segment_2;
 
     /// @}
 
-    typedef typename Container_P::difference_type difference_type;
-    typedef typename Container_P::value_type value_type;
-    typedef typename Container_P::pointer pointer;
-    typedef typename Container_P::reference reference;
-    typedef typename Container_P::const_reference const_reference;
+    typedef typename Container_::difference_type difference_type;
+    typedef typename Container_::value_type value_type;
+    typedef typename Container_::pointer pointer;
+    typedef typename Container_::reference reference;
+    typedef typename Container_::const_reference const_reference;
 
 
     //-------------------------------------------------------//
     // this intermediary step is required by Sun C++ 4.1
-    typedef typename Container_P::iterator iterator;
-    typedef typename Container_P::const_iterator const_iterator;
+    typedef typename Container_::iterator iterator;
+    typedef typename Container_::const_iterator const_iterator;
     //-------------------------------------------------------//
     typedef typename Container::iterator       Vertex_const_iterator;
-    typedef Polygon_circulator<Container_P>    Vertex_const_circulator;
+    typedef Polygon_circulator<Container_>    Vertex_const_circulator;
 
     /// \name Iterators
     ///
@@ -141,11 +141,11 @@ class Polygon_2 {
   //
 #else
     typedef Vertex_const_circulator Vertex_circulator;
-    typedef Polygon_2_edge_iterator<Traits_P,Container_P> Edge_const_iterator;
-    typedef Polygon_2_const_edge_circulator<Traits_P,
-                                            Container_P> Edge_const_circulator;
+    typedef Polygon_2_edge_iterator<Traits_,Container_> Edge_const_iterator;
+    typedef Polygon_2_const_edge_circulator<Traits_,
+                                            Container_> Edge_const_circulator;
 
-    typedef Polygon_2_edge_iterator<Traits_P,Container_P,
+    typedef Polygon_2_edge_iterator<Traits_,Container_,
                                     Tag_false> Vertex_pair_iterator;
 
   typedef Iterator_range<Edge_const_iterator> Edges;
@@ -162,7 +162,7 @@ class Polygon_2 {
     Polygon_2(const Traits & p_traits) : traits(p_traits) {}
 
     // Move constructor
-    // Polygon_2(Polygon_2<Traits_P,Container_P>&& polygon) = default;
+    // Polygon_2(Polygon_2<Traits_,Container_>&& polygon) = default;
 
     /// Creates a polygon with vertices from the sequence
     /// defined by the range \c [first,last).
@@ -260,7 +260,7 @@ class Polygon_2 {
     {
       if (size() <= 1)
         return;
-      typename Container_P::iterator i = d_container.begin();
+      typename Container_::iterator i = d_container.begin();
       std::reverse(++i, d_container.end());
     }
 
@@ -500,32 +500,32 @@ class Polygon_2 {
       { return d_container.empty(); }
 
     /// Returns a const reference to the sequence of vertices of the polygon.
-    const Container_P& container() const
+    const Container_& container() const
       { return d_container; }
 
     /// Returns a reference to the sequence of vertices of the polygon.
-    Container_P& container()
+    Container_& container()
       { return d_container; }
 
     /// Returns an iterator to the first vertex of the polygon.
-    typename Container_P::iterator begin()
+    typename Container_::iterator begin()
     {
        return container().begin();
     }
     /// Returns an iterator to the element after the last vertex of the polygon.
-    typename Container_P::iterator end()
+    typename Container_::iterator end()
     {
        return container().end();
     }
 
     /// Returns a const iterator to the first vertex of the polygon.
-    const typename Container_P::const_iterator begin() const
+    const typename Container_::const_iterator begin() const
     {
        return container().begin();
     }
 
     /// Returns a const iterator to the element after the last vertex of the polygon.
-    const typename Container_P::const_iterator end() const
+    const typename Container_::const_iterator end() const
     {
        return container().end();
     }
@@ -544,14 +544,14 @@ class Polygon_2 {
 
     /// @}
 
-    bool identical(const Polygon_2<Traits_P,Container_P> &q) const
+    bool identical(const Polygon_2<Traits_,Container_> &q) const
       { return this == &q; }
 
-    Traits_P const &traits_member() const { return traits;}
+    Traits_ const &traits_member() const { return traits;}
 
   private:
-    Container_P d_container;
-    Traits_P traits;
+    Container_ d_container;
+    Traits_ traits;
 };
 
 
@@ -563,23 +563,23 @@ class Polygon_2 {
 /// equal to the vertices of `p1`. Note that the template argument
 /// `%Container` of `p1` and `p2` may be different.
 /// \memberof Polygon_2
-template <class Traits_P, class Container1_P, class Container2_P>
-bool operator==( const Polygon_2<Traits_P,Container1_P> &p1,
-                 const Polygon_2<Traits_P,Container2_P> &p2 );
+template <class Traits_, class Container1_P, class Container2_P>
+bool operator==( const Polygon_2<Traits_,Container1_P> &p1,
+                 const Polygon_2<Traits_,Container2_P> &p2 );
 
 /// Test for inequality.
 /// \memberof Polygon_2
-template <class Traits_P, class Container1_P, class Container2_P>
+template <class Traits_, class Container1_P, class Container2_P>
 inline
 bool
-operator!=(const Polygon_2<Traits_P,Container1_P> &p1,
-           const Polygon_2<Traits_P,Container2_P> &p2);
+operator!=(const Polygon_2<Traits_,Container1_P> &p1,
+           const Polygon_2<Traits_,Container2_P> &p2);
 
 /// Returns the image of the polygon \c p under the transformation \c t.
 /// \relates Polygon_2
-template <class Transformation, class Traits_P, class Container_P>
-Polygon_2<Traits_P,Container_P>
-transform(const Transformation& t, const Polygon_2<Traits_P,Container_P>& p);
+template <class Transformation, class Traits_, class Container_>
+Polygon_2<Traits_,Container_>
+transform(const Transformation& t, const Polygon_2<Traits_,Container_>& p);
 
 /// @} // global operators
 
@@ -591,14 +591,14 @@ transform(const Transformation& t, const Polygon_2<Traits_P,Container_P>& p);
 /// Reads a polygon from stream `is` and assigns it to `p`.
 /// \pre The extract operator must be defined for `Point_2`.
 /// \relates Polygon_2
-template <class Traits_P, class Container_P>
-std::istream &operator>>(std::istream &is, Polygon_2<Traits_P,Container_P>& p);
+template <class Traits_, class Container_>
+std::istream &operator>>(std::istream &is, Polygon_2<Traits_,Container_>& p);
 
 /// Inserts the polygon `p` into the stream `os`.
 /// \pre The insert operator must be defined for `Point_2`.
 /// \relates Polygon_2
-template <class Traits_P, class Container_P>
-std::ostream &operator<<(std::ostream &os, const Polygon_2<Traits_P,Container_P>& p);
+template <class Traits_, class Container_>
+std::ostream &operator<<(std::ostream &os, const Polygon_2<Traits_,Container_>& p);
 
 /// @} // IO
 
@@ -612,11 +612,11 @@ std::ostream &operator<<(std::ostream &os, const Polygon_2<Traits_P,Container_P>
 
 namespace CGAL {
 
-template <class Traits_P, class Container1_P, class Container2_P>
+template <class Traits_, class Container1_P, class Container2_P>
 inline
 bool
-operator!=(const Polygon_2<Traits_P,Container1_P> &x,
-           const Polygon_2<Traits_P,Container2_P> &y)
+operator!=(const Polygon_2<Traits_,Container1_P> &x,
+           const Polygon_2<Traits_,Container2_P> &y)
 {
   return !(x==y);
 }
