@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Ridges_3/include/CGAL/Ridges.h $
-// $Id: include/CGAL/Ridges.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Ridges_3/include/CGAL/Ridges.h $
+// $Id: include/CGAL/Ridges.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Marc Pouget and Frédéric Cazals
@@ -336,7 +336,7 @@ Ridge_approximation(const TriangleMesh &p,
 {
   //init the is_visited_map and check that the mesh is a triangular one.
   face_iterator itb,ite;
-  boost::tie(itb,ite) = faces(P);
+  std::tie(itb,ite) = faces(P);
   for(;itb!=ite;itb++) {
     is_visited_map[*itb] = false;
   }
@@ -411,10 +411,10 @@ compute_ridges(Ridge_interrogation_type r_type, OutputIterator ridge_lines_it, R
 
   //reinit the is_visited_map
   face_iterator itb,ite;
-  boost::tie(itb,ite) = faces(P);
+  std::tie(itb,ite) = faces(P);
   for(;itb!=ite;itb++) is_visited_map[*itb] = false;
 
-  boost::tie(itb,ite) = faces(P);
+  std::tie(itb,ite) = faces(P);
   for(;itb!=ite;itb++)
     {
       face_descriptor f = *itb;
