@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh.h $
-// $Id: include/CGAL/boost/graph/properties_Surface_mesh.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Surface_mesh/include/CGAL/boost/graph/properties_Surface_mesh.h $
+// $Id: include/CGAL/boost/graph/properties_Surface_mesh.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -13,6 +13,7 @@
 #ifndef CGAL_PROPERTIES_SURFACE_MESH_H
 #define CGAL_PROPERTIES_SURFACE_MESH_H
 
+#include <type_traits>
 #ifndef DOXYGEN_RUNNING
 
 #include <CGAL/license/Surface_mesh.h>
@@ -23,6 +24,7 @@
 #include <CGAL/Kernel_traits.h>
 #include <CGAL/squared_distance_3.h>
 #include <CGAL/number_utils.h>
+#include <CGAL/utility.h>
 
 #include <CGAL/boost/graph/properties.h>
 
@@ -351,69 +353,48 @@ struct property_map<CGAL::Surface_mesh<Point>, CGAL::dynamic_edge_property_t<T>
 namespace CGAL {
 
 // get functions for dynamic properties of mutable Surface_mesh
-template <typename Point, typename T>
-typename boost::property_map<CGAL::Surface_mesh<Point>, dynamic_vertex_property_t<T> >::type
-get(dynamic_vertex_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
+template <typename Point,
+          typename Dynamic_property_tag,
+          typename = std::enable_if_t<is_dynamic_property_tag<Dynamic_property_tag>()>,
+          typename ...Default_value_args>
+auto get(Dynamic_property_tag, Surface_mesh<Point>& sm, Default_value_args&&... default_value_args)
 {
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::SMPM SMPM;
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Vertex_index, T>(std::string(), default_value).first));
-}
-
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::type
-get(dynamic_face_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::SMPM SMPM;
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Face_index, T>(std::string(), default_value).first));
-}
-
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::type
-get(dynamic_edge_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::SMPM SMPM;
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Edge_index, T>(std::string(), default_value).first));
-}
-
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::type
-get(dynamic_halfedge_property_t<T>, Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::SMPM SMPM;
-  typedef typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::type DPM;
-  return DPM(sm, new SMPM(sm.template add_property_map<typename Surface_mesh<Point>::Halfedge_index, T>(std::string(), default_value).first));
+  using BPM = typename boost::property_map<Surface_mesh<Point>, Dynamic_property_tag>;
+  using descriptor = typename Dynamic_property_tag::template property_map<Surface_mesh<Point>>::descriptor;
+  using value_type = typename Dynamic_property_tag::value_type;
+  using SMPM = typename BPM::SMPM;
+  using DPM = typename BPM::type;
+  auto&& [sm_property_map, ok] = sm.template add_property_map<descriptor, value_type>(
+      std::string(),
+      std::forward<Default_value_args>(default_value_args)...);
+  CGAL_assume(ok);
+  return DPM(sm, new SMPM(std::forward<decltype(sm_property_map)>(sm_property_map)));
 }
 
 // get functions for dynamic properties of const Surface_mesh
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_vertex_property_t<T> >::const_type
-get(dynamic_vertex_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Vertex_index, T>(num_vertices(sm), default_value);
-}
+template <typename Point,
+          typename Dynamic_property_tag,
+          typename = std::enable_if_t<is_dynamic_property_tag<Dynamic_property_tag>()>,
+          typename... Default_value_args>
+auto get(Dynamic_property_tag, const Surface_mesh<Point>& sm, Default_value_args&&... default_value_args) {
+  using graph_traits = boost::graph_traits<Surface_mesh<Point>>;
+  using face_descriptor = typename graph_traits::face_descriptor;
+  using edge_descriptor = typename graph_traits::edge_descriptor;
+  using halfedge_descriptor = typename graph_traits::halfedge_descriptor;
 
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_face_property_t<T> >::const_type
-get(dynamic_face_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Face_index, T>(num_faces(sm), default_value);
-}
+  using descriptor = typename Dynamic_property_tag::template property_map<Surface_mesh<Point>>::descriptor;
+  using value_type = typename Dynamic_property_tag::value_type;
 
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_halfedge_property_t<T> >::const_type
-get(dynamic_halfedge_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Halfedge_index, T>(num_halfedges(sm), default_value);
-}
-
-template <typename Point, typename T>
-typename boost::property_map<Surface_mesh<Point>, dynamic_edge_property_t<T> >::const_type
-get(dynamic_edge_property_t<T>, const Surface_mesh<Point>& sm, const T& default_value = T())
-{
-  return CGAL::internal::Dynamic_with_index<typename Surface_mesh<Point>::Edge_index, T>(num_edges(sm), default_value);
+  auto num_elements = num_vertices(sm);
+  if constexpr(std::is_same_v<descriptor, edge_descriptor>) {
+    num_elements = num_edges(sm);
+  } else if constexpr(std::is_same_v<descriptor, halfedge_descriptor>) {
+    num_elements = num_halfedges(sm);
+  } else if constexpr(std::is_same_v<descriptor, face_descriptor>) {
+    num_elements = num_faces(sm);
+  }
+  return CGAL::internal::Dynamic_with_index<descriptor, value_type>(
+      num_elements, std::forward<Default_value_args>(default_value_args)...);
 }
 
 // implementation detail: required by Dynamic_property_map_deleter
