@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Periodic_2_triangulation_2/include/CGAL/draw_periodic_2_triangulation_2.h $
-// $Id: include/CGAL/draw_periodic_2_triangulation_2.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Periodic_2_triangulation_2/include/CGAL/draw_periodic_2_triangulation_2.h $
+// $Id: include/CGAL/draw_periodic_2_triangulation_2.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Jasmeet Singh <jasmeet.singh.mec11@iitbhu.ac.in>
@@ -14,7 +14,7 @@
 #define DRAW_PERIODIC_2_TRIANGULATION_2_H
 
 #include <CGAL/license/Periodic_2_triangulation_2.h>
-#include <CGAL/Qt/Basic_viewer.h>
+#include <CGAL/Basic_viewer.h>
 #include <CGAL/Graphics_scene.h>
 #include <CGAL/Graphics_scene_options.h>
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
@@ -220,14 +220,17 @@ void add_to_graphics_scene(const CGAL_P2T2_TYPE& p2t2,
   add_to_graphics_scene(p2t2, graphics_scene, gs_options);
 }
 
-#ifdef CGAL_USE_BASIC_VIEWER
-
 // Specialization of draw function
 template<class Gt, class Tds, class GSOptions>
 void draw(const CGAL_P2T2_TYPE& ap2t2,
           GSOptions& gs_options,
           const char* title="2D Periodic Triangulation Viewer")
 {
+  CGAL_USE(ap2t2);
+  CGAL_USE(gs_options);
+  CGAL_USE(title);
+
+#if defined(CGAL_USE_BASIC_VIEWER)
   CGAL::Graphics_scene gs;
   add_to_graphics_scene(ap2t2, gs, gs_options);
   CGAL::Qt::QApplication_and_basic_viewer app(gs, title);
@@ -264,6 +267,7 @@ void draw(const CGAL_P2T2_TYPE& ap2t2,
     // Then we run the app
     app.run();
   }
+#endif // CGAL_USE_BASIC_VIEWER
 }
 
 template<class Gt, class Tds>
@@ -278,8 +282,6 @@ void draw(const CGAL_P2T2_TYPE& ap2t2,
   draw(ap2t2, gs_options, title);
 }
 
-#endif // CGAL_USE_BASIC_VIEWER
-
 #undef CGAL_P2T2_TYPE
 
 } // namespace CGAL
