@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Cartesian_kernel/include/CGAL/predicates/kernel_ftC3.h $
-// $Id: include/CGAL/predicates/kernel_ftC3.h e13ef800cb7 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Cartesian_kernel/include/CGAL/predicates/kernel_ftC3.h $
+// $Id: include/CGAL/predicates/kernel_ftC3.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -143,6 +143,7 @@ typename Same_uncertainty_nt<Angle, FT>::type
 angleC3(const FT &ux, const FT &uy, const FT &uz,
         const FT &vx, const FT &vy, const FT &vz)
 {
+  typedef typename Same_uncertainty_nt<CGAL::Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign(ux*vx + uy*vy + uz*vz));
 }
 
@@ -153,6 +154,7 @@ angleC3(const FT &px, const FT &py, const FT &pz,
         const FT &qx, const FT &qy, const FT &qz,
         const FT &rx, const FT &ry, const FT &rz)
 {
+  typedef typename Same_uncertainty_nt<CGAL::Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-qx)+
                                         (py-qy)*(ry-qy)+
                                         (pz-qz)*(rz-qz)));
@@ -166,6 +168,7 @@ angleC3(const FT &px, const FT &py, const FT &pz,
         const FT &rx, const FT &ry, const FT &rz,
         const FT &sx, const FT &sy, const FT &sz)
 {
+  typedef typename Same_uncertainty_nt<CGAL::Angle, FT>::type Angle;
   return enum_cast<Angle>(CGAL_NTS sign((px-qx)*(rx-sx)+
                                         (py-qy)*(ry-sy)+
                                         (pz-qz)*(rz-sz)));
@@ -220,6 +223,8 @@ coplanar_side_of_bounded_circleC3(const FT &px, const FT &py, const FT &pz,
                                   const FT &rx, const FT &ry, const FT &rz,
                                   const FT &tx, const FT &ty, const FT &tz)
 {
+  typedef typename Same_uncertainty_nt<CGAL::Bounded_side, FT>::type Bounded_side;
+
   // The approach is to compute side_of_bounded_sphere(p,q,r,t+v,t),
   // with v = pq ^ pr.
   // Note : since the circle defines the orientation of the plane, it can not
@@ -373,6 +378,7 @@ side_of_bounded_sphereC3(const FT &px, const FT &py, const FT &pz,
                          const FT &sx, const FT &sy, const FT &sz,
                          const FT &tx, const FT &ty, const FT &tz)
 {
+  typedef typename Same_uncertainty_nt<CGAL::Bounded_side, FT>::type Bounded_side;
   return enum_cast<Bounded_side>( side_of_oriented_sphereC3(px, py, pz,
                                                             qx, qy, qz,
                                                             rx, ry, rz,
@@ -392,6 +398,7 @@ side_of_bounded_sphereC3(const FT &px, const FT &py, const FT &pz,
                          const FT &tx, const FT &ty, const FT &tz)
 {
   // Returns whether T lies inside or outside the sphere which diameter is PQ.
+  typedef typename Same_uncertainty_nt<CGAL::Bounded_side, FT>::type Bounded_side;
   return enum_cast<Bounded_side>( CGAL_NTS sign((tx-px)*(qx-tx)
                                               + (ty-py)*(qy-ty)
                                               + (tz-pz)*(qz-tz)) );
@@ -420,9 +427,9 @@ side_of_bounded_sphereC3(const FT &px, const FT &py, const FT &pz,
 {
   // Returns whether T lies inside or outside the sphere which equatorial
   // circle is PQR.
+  typedef typename Same_uncertainty_nt<CGAL::Bounded_side, FT>::type Bounded_side;
 
   // This code is inspired by the one of circumcenterC3(3 points).
-
   FT psx = px-sx;
   FT psy = py-sy;
   FT psz = pz-sz;
@@ -688,7 +695,7 @@ power_side_of_oriented_power_sphereC3(const FT &pwt, const FT &qwt)
 }
 
 template < class FT >
-Comparison_result
+typename Compare<FT>::result_type
 compare_power_distanceC3(const FT &px, const FT &py, const FT &pz,
                          const FT &qx, const FT &qy, const FT &qz, const FT &qw,
                          const FT &rx, const FT &ry, const FT &rz, const FT &rw)
@@ -715,6 +722,8 @@ power_side_of_bounded_power_sphereC3(
     const FT &rx, const FT &ry, const FT &rz, const FT &rw,
     const FT &sx, const FT &sy, const FT &sz, const FT &sw)
 {
+  typedef typename Same_uncertainty_nt<Bounded_side, FT>::type Bounded_side;
+
   // Translate p to origin and compute determinants
   FT qpx = qx-px;
   FT qpy = qy-py;
@@ -765,6 +774,8 @@ power_side_of_bounded_power_sphereC3(
  const FT &qx, const FT &qy, const FT &qz, const FT &qw,
  const FT &rx, const FT &ry, const FT &rz, const FT &rw)
 {
+  typedef typename Same_uncertainty_nt<Bounded_side, FT>::type Bounded_side;
+
   FT FT2(2);
   FT dpx = px - qx;
   FT dpy = py - qy;
